import React, { useState } from 'react'
import {
    Paper,
    Table,
    TableBody,
    TableCell,
    TableHead,
    TableContainer,
    TablePagination,
    TableRow,
    IconButton,
    MenuItem,
    Tooltip,
    Icon,
} from '@material-ui/core'
import EditIcon from '@material-ui/icons/Edit'
import DeleteIcon from '@material-ui/icons/Delete'
import colors from 'app/assets/Color'
import useStyles from 'app/styles/Table'
import { Breadcrumb, SimpleCard } from 'app/components'

const columns = [
    {
        id: 'index',
        label: 'STT',
        align: 'center',
        minWidth: 80,
    },

    {
        id: 'store_name',
        label: 'Cây xăng',
        align: 'left',
        minWidth: 160,
    },
    // {
    //     id: 'application',
    //     label: 'Mã NV',
    //     align: 'left',
    //     minWidth: 140,
    // },
    {
        id: 'order_code',
        label: 'Mã hoá đơn',
        align: 'left',
        minWidth: 160,
    },
    {
        id: 'created_date',
        label: 'Ngày giao dịch',
        align: 'left',
        minWidth: 110,
    },

    // {
    //     id: 'IP',
    //     label: 'Loại nhiên liệu',
    //     align: 'left',
    //     minWidth: 140,
    // },
    {
        id: 'product_name',
        label: 'Sản phẩm',
        align: 'left',
        minWidth: 120,
    },
    {
        id: 'unit_price',
        label: 'Đơn giá',
        align: 'left',
        minWidth: 80,
    },
    {
        id: 'quantity',
        label: 'Lượng nhiên liệu',
        align: 'left',
        minWidth: 80,
    },
    {
        id: 'price',
        label: 'Thành tiền',
        align: 'left',
        minWidth: 80,
    },
    {
        id: 'type_payment',
        label: 'Phương thức thanh toán',
        align: 'left',
        minWidth: 100,
    },
    {
        id: 'status_text',
        label: 'Trạng thái',
        align: 'left',
        minWidth: 100,
    },
]

function TableList(props) {
    const classes = useStyles()
    const {
        data,
        handeChangeActive,
        removeItem,
        changeActive,
        setChangeActive,
        setPageIndex,
        setPageSize,
        pageIndex,
        totalRecords,
    } = props

    const handleChangePage = (event, newPage) => {
        setPageIndex(newPage)
    }
    const handleChangeRowsPerPage = (event) => {
        setPageSize(event.target.value)
    }

    return (
        <Paper className={classes.root}>
            <TableContainer className={classes.container}>
                <Table stickyHeader aria-label="sticky table">
                    <TableHead>
                        <TableRow>
                            {columns.map((column) => (
                                <TableCell
                                    key={column.id}
                                    align={'center'}
                                    style={{
                                        width: column.minWidth,
                                        backgroundColor: colors.headerTable,
                                    }}
                                >
                                    {column.label}
                                </TableCell>
                            ))}
                        </TableRow>
                    </TableHead>
                    <TableBody className={classes.columnTable}>
                        {data.map((row) => {
                            return (
                                <TableRow
                                    hover
                                    role="checkbox"
                                    tabIndex={-1}
                                    key={row.id}
                                >
                                    {columns.map((column) => {
                                        const avatar = row[column.id]

                                        return (
                                            <TableCell
                                                key={column.id}
                                                align={column.align}
                                            >
                                                {column.format ? (
                                                    <img
                                                        src={column.format(
                                                            avatar
                                                        )}
                                                        className={
                                                            classes.image
                                                        }
                                                    />
                                                ) : (
                                                    avatar
                                                )}
                                            </TableCell>
                                        )
                                    })}
                                </TableRow>
                            )
                        })}
                    </TableBody>
                </Table>
            </TableContainer>
            <TablePagination
                component="div"
                page={pageIndex}
                count={totalRecords}
                rowsPerPage={10}
                rowsPerPageOptions={[]}
                onChangePage={handleChangePage}
                onChangeRowsPerPage={handleChangeRowsPerPage}
            />
        </Paper>
    )
}

export default TableList
